function check_model_media_sets_v3( media_file, j_model_file, write2file, start, stop )
% Usage: check_model_media_sets_v3( media_file, j_model_file, write2file, start, stop ) 
% Purpose:  This script finds the max amount of growth for each model for a list of
%   media conditons
% Inputs:
%   media_file      - name of file with media, needs to be comma delimited, uniform 
%                     number of rows, use zeros as place holders
%   j_model_file    - name of joined model file ( like 'Joined_model1.mat' )
%   write2file      - name of file to output to
%   start           - row of media file to start at
%   stop            - row of media file to stop  at
% Outputs:
%   nothing
% Author:   Niels
% Date:     
% Notes:    Updated 10/07/13, optimized and clean up code - niels
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% load models
%joined
model = load( j_model_file );
model_name = fieldnames(  model );
joined_model = model.(model_name{1});
joined_model.S = sparse( joined_model.S );

%% load replacement sets and generate 
media_sets =  textread( media_file, '', 'delimiter', ',' );

if ( ischar( start ) )
    start = str2num( start );
end

if( ischar( stop ) )
    stop = str2num( stop );
end

media_sets = media_sets([start:stop],:);

%disp( 'loaded models and added media' );

file_1 = fopen(write2file,'w');
fprintf( 'processing from start: %d stop: %d\n', start, stop);

for k=1:size(media_sets,1)
    
    if ( iscell( media_sets ) )
        media_set = media_sets{k};
        media_set = media_set(logical(media_set));
    else
        media_set = media_sets(k,:);
        media_set = media_set(logical(media_set)); 
    end
        
    [growth_class, growth_values] = check_interaction( joined_model, media_set );
    
    result_vector = [ growth_values, media_set ];
    result_string = num2str( result_vector(1) );

    for i = 2:length( result_vector )
        result_string = [ result_string, ',', num2str( result_vector(i) ) ];
    end
    
    fprintf(file_1, [ result_string, '\n' ]);
  
end

fclose(file_1);


end
