function [ rxn_string ] = display_rxn( S, mets, rxn_no, fv )
%function [ rxn_string ] = display_rxn( S, mets, rxn_no )
%   builds a rxn string for a particular rxn line in a stoichiometric line
%   
% inputs:
%   S       = model.S;
%   mets    = model.mets;
%   rxn_no  = 
%   fv      = complete value of stoiomitry

%check if we got a model first, reassign values as nessiary
if ( isstruct( S ) )
    model = S;
    
    if ( exist( 'rxn_no', 'var' ) )
        fv = rxn_no;
    else
        fv = 0;
    end
    
    rxn_no = mets;
    
    if ( all( isfield( model, {'S','mets'} ) ) )
        S    = model.S;
        mets = model.mets;
        if ( isfield( model, 'lb' ) ), lb = model.lb(rxn_no); end;
        if ( isfield( model, 'ub' ) ), ub = model.ub(rxn_no); end;
    else
        error( 'Error: unknown structure passed in' );
    end
end

%set lb and ub if not found in model;
if ( ~exist( 'lb', 'var' ) ), lb = -1; end;
if ( ~exist( 'ub', 'var' ) ), ub = 1;  end;
if ( ~exist( 'fv', 'var' ) ), fv = 0;  end;

% get rxn stociometry
rxn = S(:,rxn_no);

reactants = [];
products  = [];

% determin products and reactants
for i = 1:length( rxn )
    if ( rxn(i,1) < 0 )
        reactants = [reactants, i];
    end
    
    if ( rxn(i,1) > 0 )
        products = [products, i];
    end
end

rxn_string = '';

% create reactant portion of the string
for i = 1:(length( reactants ) -1)
    
    if ( fv )
        count = num2str( (-1 * S(reactants(i),rxn_no) ) );
        count = ['(' count ')' ];
    else
        count = sprintf( '(%2.2f)', (-1 * S(reactants(i),rxn_no) ) );
    end
    
    rxn_string = strcat( rxn_string, count, mets(reactants(i)), '+' );
end

% create joining symbol
if ( (lb < 0) && ( ub > 0 ) )
    joining_symbol = '<=>';
elseif ( lb < 0  )
    joining_symbol = '<=|';
elseif ( ub > 0 )
    joining_symbol = '|=>';
else 
    joining_symbol = '|=|';
end

if ( ~ isempty( reactants ) )
    
    if ( fv )
        count = num2str(  (-1 * S(reactants(length( reactants )),rxn_no) ) );
        count = ['(' count ')' ];
    else
        count = sprintf( '(%2.2f)', (-1 * S(reactants(length( reactants )),rxn_no) ) );
    end
    
    rxn_string = strcat( rxn_string, count, mets(reactants(length( reactants ))),  joining_symbol );
else
    rxn_string = strcat( 'nothing', joining_symbol );
end
    
for i = 1:(length( products ) -1)
    
    if ( fv )
        count = num2str(  ( S(products(i),rxn_no) ) );
        count = ['(' count ')' ];
    else
        count = sprintf( '(%2.2f)', ( S(products(i),rxn_no) ) );
    end
    
    rxn_string = strcat( rxn_string, count, mets(products(i)), '+' );
end

if ( ~ isempty( products ) )
    
    if ( fv )
        count = num2str( S(products(length( products )),rxn_no) );
        count = ['(' count ')' ];
    else
        count = sprintf( '(%2.2f)', ( S(products(length( products )),rxn_no) ) );
    end
        
    rxn_string = strcat( rxn_string, count, mets(products( length( products ))) );
else
    rxn_string = strcat( rxn_string, 'nothing' );
end

rxn_string = cellstr( rxn_string );

