function  find_model_replacement_sets(model_file, write_dir, base_media_set)
% usage: find_model_replacement_sets(model_file, write_dir, base_media_set)
% description: for a joined model finds the replacement set for 'base_media_set'
% author: Niels
% date:
% Notes: Updated 10/07/14 - cleaned up code - niels
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% standared minerals to exclude from replacement sets
% these will always be available to the model, and will not be inlcuded in the
% search for replacements sets
minerals = {'o2\W',     'na1\W', 'fe2\W',   'fe3\W', 'mg2\W', 'mn2\W', ...
            'h2o\W',    'ca2\W', 'cl\W',    'cd2\W', 'cu2\W', 'k\W', ...
            'cobalt2\W','hg2\W', 'tungs\W', 'zn2\W', 'ni2\W', 'mobd\W'};

%load model
model = load( model_file );
model_name = fieldnames(  model );
model = model.(model_name{1});

%find mineral_ids 
mineral_set = zeros( length(  minerals ), 1 );
for i=1:length( minerals )
    rxn = find_ex_rxns( model, minerals{i} );
    if ( length( rxn ) == 1 )
        mineral_set(i) = rxn;
    end
end
mineral_set = mineral_set( logical(mineral_set) );

%find media ids
media_set = zeros( length( base_media_set ), 1 );
for i=1:length( media_set )
    media_set(i) = find_ex_rxns( model, base_media_set{i} );
end

%test media set to see if we are still missing metabolites 
%(co-factores, other minerals, etc... )
[a,b] = get_environment( model, 0 );
model.lb( b ) = 0;
model.lb( media_set ) = -100;
model.lb( mineral_set ) = -100;
model.media = zeros( size( model.lb));
model.media(b) = 1;
model.media( media_set ) = 0;
model.media( mineral_set ) = 0;
model.lb( logical( model.c) ) = .1;
[missing] = find_min_media( model );

if ( ~isempty( missing ) )
    disp( 'Missing metoblites from model for a feasible solution:' );
    model.rxns(missing')
    % add these missing reactions to the mineral sets 
    % These will always be allowed and excluded from future searches
    mineral_set = union( mineral_set, missing );
    model.media( mineral_set ) = 0;
    model.lb( mineral_set ) = -100;
end

% confirm the model works as is
[v,e] = FBA( model );
if( e ~= 5 )
    error( 'model still not working! %d\n', e );
else
    disp( 'Minerals in the base media set:\n' );
    model.rxns{mineral_set}
    disp( 'Metabolites that replacement sets will be found for:\n' );
    model.rxns{media_set}
end

%find replacement set
[replacement_set] = find_replacement_sets( model, media_set, mineral_set);  


%write replacemnt set
rep_file = [write_dir '/' model.model_names{1} '_' model.model_names{2} '_rs.csv' ];
write_list( replacement_set, rep_file );

end

