function replacement_set = find_replacement_sets( model, media_set, exclude_set )
%Usage: replacement_set = find_replacement_sets( model, media_set )
% Desc: finds all replacement metabolites for mets in media set
% Inputs:
%   model           An COBRA style FBA model
%   media_set:      vector of metabolites exchange reactions in media to test
%   exclude_sets:   vector of metaoblites exchange reactions in media not to test
% Output: 
%   replacement_set = list of feasible replacement metaoblites sets (ie: media)
% Author: Niels
% Date: Dec 16, 2009
% Notes:  Updated 10/07/14 cleaned up code - niels
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% make S sparse, cause this speeds the bugger up...
model.S = sparse( model.S );
base_media = media_set;

% remove required media members from conderation....
[x,media_members] = get_environment( model, 0 );
media_members = setdiff( media_members, media_set );
media_members = setdiff( media_members, exclude_set )

%set the feasible media...
model.media = zeros( size( model.lb ) );
model.media( media_members ) = 1;

if ( ~ isfield( model, 'bm' ) )
    model.bm = 1;
end

% all media off 
model.lb( media_members ) = 0;

% add back required metabolites and media
model.lb( exclude_set ) = -1000;
model.lb( media_set) = -100;

replacement_set = {};
replacement_set{1} = union( media_set, exclude_set );

% now we start on the first round of iteration
for k=1:length( base_media )
    
    % select met to disable
    met = base_media(k);
    % and get it's compliment.
    met_comp = setdiff( base_media, met );
    
    %set media members, remove base media from solution
    model.media(media_members) = 1;

    
    %allow flux through base media, disallow the met being assayed.
    model.lb( base_media ) = -100;
    model.lb( met ) = 0;
       
    % finds all metabolites and metabolite subsets that can replace the deactivated met
    met_alternates = get_alt_min_media( model);
    
    % record results...
    for j=1:length( met_alternates )
        
        min_media = union(  met_comp, met_alternates{j} );
        media = union( min_media, exclude_set );
        replacement_set{length(replacement_set) + 1,1} = media;
        
    end
    
end

end

