function [ results ] = get_alt_min_media( model )
%[ results ] = get_alt_min_media( model )
%  Descriptoin:  finds all alternative minimal media for a fba model
%
%  Params:  model -> palsson style model, expected to contain:
%               S, lb, ub, c, media
%           results -> cell array of minimal medias
%
%  Author: Niels
%  Date:   Nov 13 2008
%  Notes:
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%find solution to current model
[minimal, status] = find_min_media( model );
   
results = {};

% if not feasible, return empty cell array
if ( status ~= 5 )
    return;
else
    
    % this should not happen, but....
    if ( length( minimal) < 1 )
        sprintf( 'Status was %d', status );
        
        [a,media] = get_environment( model );
        
        return ;
    end
    
    %record minimal media
    results{1} = minimal;
    
    % remove minimal media from future solutions
    model.media( minimal ) = 0;
    
    %find media alternates for each member of media
    for i=1:length( minimal )
        
        met = minimal(i);

        met_name = model.rxns{met};
        comp_met = setdiff( minimal, met );
    
        %allow no cost compliment of met
        model.lb( comp_met ) = -100;
        % dis-allow met
        model.lb( met ) = 0;
        
        it_results = get_alt_min_media( model );
        
        % concantinate results to complicment of met
        for j=1:length( it_results )
            results{length(results)+1} = union(  comp_met, it_results{j} );
        end
    end
end
            

