function [ met_map, number_shared ] =map_mets( mets1, mets2, loc1, loc2  )
%[ met_map ] = join_mets( mets1, mets2, loc1, loc2  )
%   Purpose: This script maps metabolites from mets1 to mets2 in loc1/loc2
%            Each metabolite in (any) loc1 is joined with the same
%            metabolite name in (any) loc2.
%
%   variables:
%     input:
%       mets1/mets2 - cell array of char ( the metabolite arrays to join )
%       loc1/loc2   - char of metabolite locations to join one, can be more
%                     than 1 (typicaly one or more in {ecmpn} )
%     output:
%       met_map     - matrix mapping mets1 to mets2
%
%   Auther: Niels 
%   Date:   2009 April 7
%   Notes:
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% parameter set up
met_locations = struct; % holds met name and matrix locations of each met found;

mets1_length = length(mets1);
mets2_length = length(mets2);

met_map = zeros( mets1_length, mets2_length );
number_shared = 0;

% sets up pattern matching
pat1 = strcat( '(?<met>.+)[\_\(\[][', loc1, '][\]\)\_]$' );
pat2 = strcat( '(?<met>.+)[\_\(\[][', loc2, '][\]\)\_]$' );

% process first list
for i = 1:mets1_length;
    
    % format met properly to be a field... (can't start with number, remove
    % weird chars)
    met = strcat( 'm_', mets1{i} );
    met = regexprep( met, '[\(\[\]\)\-\,\:]', '_' );

    re_result = regexp( met, pat1, 'names' );

    if ( ~ isempty( re_result )  )
        met_id = re_result.met;
        
        %assign position
        met_locations.(met_id) = i;
        
    else
        %do nothing...
    end
    
end

%now second list of mets
for i = 1:mets2_length
    
    % format met properly to be a field...
    met = strcat( 'm_' , mets2{i} );
    met = regexprep( met, '[\(\[\]\)\-\,\:]', '_' );


    % check metabolite to see if it is to be collapsed
    re_result = regexp( met, pat2, 'names' );

    % rename metabolite to remove location.
    if ( ~ isempty( re_result )  )
        met_id = re_result.met;
        
        %have we seen this met yet?
        if ( isfield( met_locations, met_id) )
            position = met_locations.(met_id);
            met_map(position, i ) = 1;
            number_shared = number_shared + 1;
        else
            %do nothing if we haven't
        end
    else
        % ignore if not a desired location.
    end
    
end

end
